diff --git a/comments.php b/comments.php
index d6a733e..bb5ee06 100644
--- a/comments.php
+++ b/comments.php
@@ -4,12 +4,12 @@
*
* The area of the page that contains both current comments
* and the comment form. The actual display of comments is
- * handled by a callback to twentytwelve_comment() which is
+ * handled by a callback to bugcrowd_comment() which is
* located in the functions.php file.
*
* @package WordPress
- * @subpackage Twenty_Twelve
- * @since Twenty Twelve 1.0
+ * @subpackage Bugcrowd
+ * @since Bugcrowd 1.0
*/
/*
@@ -28,20 +28,20 @@
+
+
diff --git a/editor-style-rtl.css b/editor-style-rtl.css
index 5fd832c..0eefac3 100644
--- a/editor-style-rtl.css
+++ b/editor-style-rtl.css
@@ -1,5 +1,5 @@
/*
-Theme Name: Twenty Twelve
+Theme Name: Bugcrowd
Description: Used to style the TinyMCE editor for RTL languages.
See also rtl.css file.
*/
diff --git a/editor-style.css b/editor-style.css
index 24e9b24..79fb0a8 100644
--- a/editor-style.css
+++ b/editor-style.css
@@ -1,5 +1,5 @@
/*
-Theme Name: Twenty Twelve
+Theme Name: Bugcrowd
Description: Used to style the TinyMCE editor.
*/
diff --git a/footer.php b/footer.php
index 79848d3..f6d75b2 100644
--- a/footer.php
+++ b/footer.php
@@ -5,17 +5,27 @@
* Contains footer content and the closing of the #main and #page div elements.
*
* @package WordPress
- * @subpackage Twenty_Twelve
- * @since Twenty Twelve 1.0
+ * @subpackage Bugcrowd
+ * @since Bugcrowd 1.0
*/
-?>
+?>
+
-
+
+
diff --git a/functions.php b/functions.php
index 4054481..23d0085 100644
--- a/functions.php
+++ b/functions.php
@@ -1,6 +1,6 @@
'e6e6e6',
- ) );
+
+ register_nav_menu( 'primary', __( 'Footer Menu', 'bugcrowd' ) );
// This theme uses a custom image size for featured images, displayed on "standard" posts.
add_theme_support( 'post-thumbnails' );
set_post_thumbnail_size( 624, 9999 ); // Unlimited height, soft crop
}
-add_action( 'after_setup_theme', 'twentytwelve_setup' );
+add_action( 'after_setup_theme', 'bugcrowd_setup' );
-/**
- * Add support for a custom header image.
- */
-require( get_template_directory() . '/inc/custom-header.php' );
/**
* Return the Google font stylesheet URL if available.
@@ -88,23 +79,23 @@ function twentytwelve_setup() {
* The use of Open Sans by default is localized. For languages that use
* characters not supported by the font, the font can be disabled.
*
- * @since Twenty Twelve 1.2
+ * @since Bugcrowd 1.2
*
* @return string Font stylesheet or empty string if disabled.
*/
-function twentytwelve_get_font_url() {
+function bugcrowd_get_font_url() {
$font_url = '';
/* translators: If there are characters in your language that are not supported
* by Open Sans, translate this to 'off'. Do not translate into your own language.
*/
- if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'twentytwelve' ) ) {
+ if ( 'off' !== _x( 'on', 'Open Sans font: on or off', 'bugcrowd' ) ) {
$subsets = 'latin,latin-ext';
/* translators: To add an additional Open Sans character subset specific to your language,
* translate this to 'greek', 'cyrillic' or 'vietnamese'. Do not translate into your own language.
*/
- $subset = _x( 'no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'twentytwelve' );
+ $subset = _x( 'no-subset', 'Open Sans font: add new subset (greek, cyrillic, vietnamese)', 'bugcrowd' );
if ( 'cyrillic' == $subset )
$subsets .= ',cyrillic,cyrillic-ext';
@@ -127,11 +118,11 @@ function twentytwelve_get_font_url() {
/**
* Enqueue scripts and styles for front-end.
*
- * @since Twenty Twelve 1.0
+ * @since Bugcrowd 1.0
*
* @return void
*/
-function twentytwelve_scripts_styles() {
+function bugcrowd_scripts_styles() {
global $wp_styles;
/*
@@ -142,47 +133,20 @@ function twentytwelve_scripts_styles() {
wp_enqueue_script( 'comment-reply' );
// Adds JavaScript for handling the navigation menu hide-and-show behavior.
- wp_enqueue_script( 'twentytwelve-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );
+ wp_enqueue_script( 'bugcrowd-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '1.0', true );
- $font_url = twentytwelve_get_font_url();
+ $font_url = bugcrowd_get_font_url();
if ( ! empty( $font_url ) )
- wp_enqueue_style( 'twentytwelve-fonts', esc_url_raw( $font_url ), array(), null );
+ wp_enqueue_style( 'bugcrowd-fonts', esc_url_raw( $font_url ), array(), null );
// Loads our main stylesheet.
- wp_enqueue_style( 'twentytwelve-style', get_stylesheet_uri() );
+ wp_enqueue_style( 'bugcrowd-style', get_stylesheet_uri() );
// Loads the Internet Explorer specific stylesheet.
- wp_enqueue_style( 'twentytwelve-ie', get_template_directory_uri() . '/css/ie.css', array( 'twentytwelve-style' ), '20121010' );
- $wp_styles->add_data( 'twentytwelve-ie', 'conditional', 'lt IE 9' );
+ wp_enqueue_style( 'bugcrowd-ie', get_template_directory_uri() . '/css/ie.css', array( 'bugcrowd-style' ), '20121010' );
+ $wp_styles->add_data( 'bugcrowd-ie', 'conditional', 'lt IE 9' );
}
-add_action( 'wp_enqueue_scripts', 'twentytwelve_scripts_styles' );
-
-/**
- * Filter TinyMCE CSS path to include Google Fonts.
- *
- * Adds additional stylesheets to the TinyMCE editor if needed.
- *
- * @uses twentytwelve_get_font_url() To get the Google Font stylesheet URL.
- *
- * @since Twenty Twelve 1.2
- *
- * @param string $mce_css CSS path to load in TinyMCE.
- * @return string Filtered CSS path.
- */
-function twentytwelve_mce_css( $mce_css ) {
- $font_url = twentytwelve_get_font_url();
-
- if ( empty( $font_url ) )
- return $mce_css;
-
- if ( ! empty( $mce_css ) )
- $mce_css .= ',';
-
- $mce_css .= esc_url_raw( str_replace( ',', '%2C', $font_url ) );
-
- return $mce_css;
-}
-add_filter( 'mce_css', 'twentytwelve_mce_css' );
+add_action( 'wp_enqueue_scripts', 'bugcrowd_scripts_styles' );
/**
* Filter the page title.
@@ -190,13 +154,13 @@ function twentytwelve_mce_css( $mce_css ) {
* Creates a nicely formatted and more specific title element text
* for output in head of document, based on current view.
*
- * @since Twenty Twelve 1.0
+ * @since Bugcrowd 1.0
*
* @param string $title Default title text for current view.
* @param string $sep Optional separator.
* @return string Filtered title.
*/
-function twentytwelve_wp_title( $title, $sep ) {
+function bugcrowd_wp_title( $title, $sep ) {
global $paged, $page;
if ( is_feed() )
@@ -212,38 +176,38 @@ function twentytwelve_wp_title( $title, $sep ) {
// Add a page number if necessary.
if ( $paged >= 2 || $page >= 2 )
- $title = "$title $sep " . sprintf( __( 'Page %s', 'twentytwelve' ), max( $paged, $page ) );
+ $title = "$title $sep " . sprintf( __( 'Page %s', 'bugcrowd' ), max( $paged, $page ) );
return $title;
}
-add_filter( 'wp_title', 'twentytwelve_wp_title', 10, 2 );
+add_filter( 'wp_title', 'bugcrowd_wp_title', 10, 2 );
/**
* Filter the page menu arguments.
*
* Makes our wp_nav_menu() fallback -- wp_page_menu() -- show a home link.
*
- * @since Twenty Twelve 1.0
+ * @since Bugcrowd 1.0
*/
-function twentytwelve_page_menu_args( $args ) {
+function bugcrowd_page_menu_args( $args ) {
if ( ! isset( $args['show_home'] ) )
$args['show_home'] = true;
return $args;
}
-add_filter( 'wp_page_menu_args', 'twentytwelve_page_menu_args' );
+add_filter( 'wp_page_menu_args', 'bugcrowd_page_menu_args' );
/**
* Register sidebars.
*
* Registers our main widget area and the front page widget areas.
*
- * @since Twenty Twelve 1.0
+ * @since Bugcrowd 1.0
*/
-function twentytwelve_widgets_init() {
+function bugcrowd_widgets_init() {
register_sidebar( array(
- 'name' => __( 'Main Sidebar', 'twentytwelve' ),
+ 'name' => __( 'Main Sidebar', 'bugcrowd' ),
'id' => 'sidebar-1',
- 'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'twentytwelve' ),
+ 'description' => __( 'Appears on posts and pages except the optional Front Page template, which has its own widgets', 'bugcrowd' ),
'before_widget' => '',
'before_title' => '
',
@@ -251,9 +215,9 @@ function twentytwelve_widgets_init() {
) );
register_sidebar( array(
- 'name' => __( 'First Front Page Widget Area', 'twentytwelve' ),
+ 'name' => __( 'First Front Page Widget Area', 'bugcrowd' ),
'id' => 'sidebar-2',
- 'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve' ),
+ 'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'bugcrowd' ),
'before_widget' => '',
'before_title' => '
',
@@ -261,52 +225,52 @@ function twentytwelve_widgets_init() {
) );
register_sidebar( array(
- 'name' => __( 'Second Front Page Widget Area', 'twentytwelve' ),
+ 'name' => __( 'Second Front Page Widget Area', 'bugcrowd' ),
'id' => 'sidebar-3',
- 'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'twentytwelve' ),
+ 'description' => __( 'Appears when using the optional Front Page template with a page set as Static Front Page', 'bugcrowd' ),
'before_widget' => '',
'before_title' => '
diff --git a/archive.php b/archive.php
index 2d442bd..91672f8 100644
--- a/archive.php
+++ b/archive.php
@@ -6,15 +6,15 @@
* For example, puts together date-based pages if no date.php file exists.
*
* If you'd like to further customize these archive views, you may create a
* new template file for each specific one. For example, Twenty Twelve already
* has tag.php for Tag archives, category.php for Category archives, and
* author.php for Author archives.
*
* @link http://codex.wordpress.org/Template_Hierarchy
*
* @package WordPress
- * @subpackage Twenty_Twelve
- * @since Twenty Twelve 1.0
+ * @subpackage Bugcrowd
+ * @since Bugcrowd 1.0
*/
get_header(); ?>
@@ -26,13 +26,13 @@
@@ -37,7 +37,7 @@
endwhile;
- twentytwelve_content_nav( 'nav-below' );
+ bugcrowd_content_nav( 'nav-below' );
?>
@@ -6,15 +6,15 @@
*
* If you'd like to further customize these archive views, you may create a
- * new template file for each specific one. For example, Twenty Twelve already
+ * new template file for each specific one. For example, Bugcrowd already
* has tag.php for Tag archives, category.php for Category archives, and
* author.php for Author archives.